@@ -8,12 +8,8 @@ from adlinear import nmfmodel as nmf
 from randomgenerators import randomgenerators as rng
 import dotenv
 
-use_gcs = False
-if use_gcs:
-    Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
-    dotenv.load_dotenv()
-else:
-    Path.set_global_fs("local")
+Path.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
+dotenv.load_dotenv()
 
 if __name__ == "__main__":
 
