@@ -198,6 +198,13 @@ if __name__ == "__main__":
         except ValueError as e:
             print("SkLearn NMF does not take missing values !")
 
+    do_screeplot = os.getenv("esg_do_screeplot", "False").lower() == "true"
+    if do_screeplot:
+        ncmin = 3
+        ncmax = 12
+        df_scree_plot = nmf.generate_scree_plot(M_unfilled, ncmin=ncmin, ncmax=ncmax)
+        df_scree_plot.to_csv(out_data_path/"ESG_unfilled_screeplot.csv")
+
     do_imputation_test = os.getenv("esg_do_imputation_test", "False").lower() == "true"
     if do_imputation_test:
         nmf6_missing, _ = tst.compare_full_sparse_nmf_model(M_unfilled, ncomp=6, sparsity=0.0, nfills=0)
@@ -211,7 +218,47 @@ if __name__ == "__main__":
 
     do_stats_on_variables = os.getenv("esg_do_stats_on_variables", "False").lower() == "true"
     if do_stats_on_variables:
+        df_avg_sect = pd.DataFrame(index=set(np.unique(df_sectors)),
+                                   columns=M_unfilled.columns,
+                                   data=0)
+        df_max_sect = pd.DataFrame(index=set(np.unique(df_sectors)),
+                                   columns=M_unfilled.columns,
+                                   data=0)
+        df_minvars_by_sectors = pd.DataFrame(index=set(np.unique(df_sectors)),
+                                             columns=M_unfilled.columns)
+        df_nbstocks_by_sectors = pd.DataFrame(index=set(np.unique(df_sectors)),
+                                              columns=M_unfilled.columns,
+                                              data=0)
+        for col in M_unfilled.columns:
+            for isin in M_unfilled.index:
+                if isin in df_sectors.index:
+                    sector = df_sectors.loc[isin].iloc[0]
+                    val = M_unfilled.loc[isin, col]
+                    if not pd.isnull(val):
+                        df_nbstocks_by_sectors.loc[sector, col] += 1
+                        df_avg_sect.loc[sector, col] += val
+                        df_max_sect.loc[sector, col] = np.nanmax([df_max_sect.loc[sector, col],
+                                                                  val])
+                        df_minvars_by_sectors.loc[sector, col] = np.nanmin([df_minvars_by_sectors.loc[sector, col],
+                                                                            val])
+        df_avg_sect = np.divide(df_avg_sect, df_nbstocks_by_sectors)
+        df_avg_sect.loc["BestAvg", :] = np.nanmax(df_avg_sect, axis=0)
+        df_avg_sect.loc["WorstAvg", :] = np.nanmin(df_avg_sect, axis=0)
+        df_avg_sect.loc["Dispersion", :] = df_avg_sect.loc["BestAvg", :] - df_avg_sect.loc["WorstAvg", :]
+        df_avg_sect.loc["WorstSector", :] = df_avg_sect.index[np.apply_over_axes(np.argmin,
+                                                                                 df_avg_sect.iloc[0:-3, :],
+                                                                                 axes=0)]
+        df_avg_sect.loc["BestSector", :] = df_avg_sect.index[np.apply_over_axes(np.argmax,
+                                                                                df_avg_sect.iloc[0:-3, :],
+                                                                                axes=0)]
 
+        df_avg_sect.loc[:, "BestScore"] = df_avg_sect.columns[np.apply_over_axes(np.argmax,
+                                                                                 df_avg_sect.iloc[:, :],
+                                                                                 axes=1)]
+        df_avg_sect.loc[:, "WorstScore"] = df_avg_sect.index[np.apply_over_axes(np.argmin,
+                                                                                df_avg_sect.iloc[:, 0:-1],
+                                                                                axes=1)]
+        df_avg_sect.to_csv(out_data_path / "df_avg_by_sectors.csv")
         pass
 
     do_features = False
@@ -250,7 +297,7 @@ if __name__ == "__main__":
             columns=["ncomp", "effective_dim", "sparsity", "error", "Clustering entropy", "Matrix entropy", "Delta"],
         )
         nmf6, _ = tst.compare_full_sparse_nmf_model(M_filled, ncomp=6, sparsity=0.0, drop_unrelevant=False,
-                                                    do_plot=True)
+                                                    do_plot=True, pictures_path=pictures_path)
         df_comparison.loc["nmf", "ncomp"] = nmf6.ncomp
         df_comparison.loc["nmf", "effective_dim"] = nmf6.get_effective_dimension()
         df_comparison.loc["nmf", "sparsity"] = nmf6.get_target_sparsity()
@@ -261,7 +308,7 @@ if __name__ == "__main__":
 
         sp_nmf6, restricted_nmf6 = tst.compare_full_sparse_nmf_model(M_filled, ncomp=6, sparsity=0.9,
                                                                      drop_unrelevant=True,
-                                                                     do_plot=True)
+                                                                     do_plot=True, pictures_path=pictures_path)
         df_comparison.loc["sparse_nmf", "ncomp"] = sp_nmf6.ncomp
         df_comparison.loc["sparse_nmf", "effective_dim"] = sp_nmf6.get_effective_dimension()
         df_comparison.loc["sparse_nmf", "sparsity"] = sp_nmf6.get_target_sparsity()
@@ -285,7 +332,7 @@ if __name__ == "__main__":
 
         sp_snmf6, _ = tst.compare_full_sparse_nmf_model(M_filled, ncomp=6, nblocks=2, sparsity=0.0, nfills=5,
                                                         drop_unrelevant=False,
-                                                        do_plot=True)
+                                                        do_plot=True, pictures_path=pictures_path)
         # noinspection PyProtectedMember
         df_comparison.loc["snmf", "ncomp"] = sp_snmf6._ncomp
         df_comparison.loc["snmf", "effective_dim"] = sp_snmf6.get_effective_dimension()
@@ -298,7 +345,8 @@ if __name__ == "__main__":
 
         sp_snmf6, restricted_snmf6 = tst.compare_full_sparse_nmf_model(M_filled, ncomp=6, nblocks=2, sparsity=0.9,
                                                                        nfills=5,
-                                                                       drop_unrelevant=True, do_plot=True)
+                                                                       drop_unrelevant=True,
+                                                                       do_plot=True, pictures_path=pictures_path)
         # noinspection PyProtectedMember
         df_comparison.loc["sparse_snmf", "ncomp"] = sp_snmf6._ncomp
         df_comparison.loc["sparse_snmf", "effective_dim"] = sp_snmf6.get_effective_dimension()
