@@ -58,10 +58,10 @@ if __name__ == "__main__":
         df_log_brunet = df_brunet - np.nanmin(df_brunet, axis=0)
         df_log_brunet = np.log(1.0 + df_log_brunet)
 
-        nmf_brunet = nmf.NmfModel(mat=df_brunet, name="brunet",
-                                  ncomp=ncomp_brunet, regularization="components", leverage="robust", max_iter=200)
-        nmf_log_brunet = nmf.NmfModel(mat=df_log_brunet, name="log_brunet",
-                                      ncomp=ncomp_brunet, regularization="components", leverage="robust", max_iter=200)
+        nmf_brunet = nmf.NmfModel(mat=df_brunet, ncomp=ncomp_brunet, name="brunet", leverage="robust", max_iter=200,
+                                  regularization="components")
+        nmf_log_brunet = nmf.NmfModel(mat=df_log_brunet, ncomp=ncomp_brunet, name="log_brunet", leverage="robust",
+                                      max_iter=200, regularization="components")
 
         if os.getenv("imp_do_brunet_screeplot", "False").lower() == "true":
             ncmin = 1
